@@ -2,6 +2,6 @@
 Fake data for testing LibreLingo-related packages
 """
 
-from librelingo_types.fakes import *
+from librelingo_fakes.fakes import *
 
-__version__ = '0.1.0'
+__version__ = '0.1.2'
